@@ -1,6 +1,6 @@
 from .about import __version__, __download_url__, __title__
 
-from .util import augmenters, docs, texts, keyboards, load
+from .util import augmenters, docs, texts, keyboards, load, meta
 
 # import augmenters
 from .character import (
